% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 1121.591454764994978 ; 1120.346547823328820 ];

%-- Principal point:
cc = [ 442.175013781277414 ; 475.514939426947365 ];

%-- Skew coefficient:
alpha_c = 0.000000000000000;

%-- Distortion coefficients:
kc = [ -0.196153596025584 ; 0.268454527003891 ; -0.009764961898201 ; 0.000754221841717 ; 0.000000000000000 ];

%-- Focal length uncertainty:
fc_error = [ 6.036030237862892 ; 6.015623353073610 ];

%-- Principal point uncertainty:
cc_error = [ 5.807753670937101 ; 7.956894362576455 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.000000000000000;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.036167953463917 ; 0.597677506769921 ; 0.001554058408608 ; 0.001309995470436 ; 0.000000000000000 ];

%-- Image size:
nx = 1004;
ny = 1004;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 1;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 0;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 0 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ 6.215107e-01 ; -2.120924e+00 ; 1.591003e+00 ];
Tc_1  = [ 1.351498e+03 ; 3.275014e+02 ; 3.480660e+03 ];
omc_error_1 = [ 6.884942e-03 ; 5.045738e-03 ; 1.338741e-02 ];
Tc_error_1  = [ 8.318233e+00 ; 1.135357e+01 ; 8.975348e+00 ];

